@@ -2,9 +2,10 @@
     Deblocking functions.
 """
 from functools import partial
-from typing import Optional, Sequence, Tuple
+from typing import Any, Optional, Sequence, Tuple, Union
 
 import vapoursynth as vs
+from vsutil import depth
 
 from .types import Matrix
 from .util import get_prop
@@ -12,10 +13,14 @@ from .util import get_prop
 core = vs.core
 
 
+dpir_warning = "vsdpir and pytorch are required for this function. " + \
+               "vsdpir can be installed with 'pip install vsdpir'."
+
+
 def autodb_dpir(clip: vs.VideoNode, edgevalue: int = 24,
                 strs: Sequence[float] = [30, 50, 75],
                 thrs: Sequence[Tuple[float, float, float]] = [(1.5, 2.0, 2.0), (3.0, 4.5, 4.5), (5.5, 7.0, 7.0)],
-                matrix: Optional[Matrix] = None,
+                matrix: Optional[Union[Matrix, int]] = None,
                 cuda: bool = True, device_index: int = 0,
                 write_props: bool = False
                 ) -> vs.VideoNode:
@@ -58,8 +63,7 @@ def autodb_dpir(clip: vs.VideoNode, edgevalue: int = 24,
     try:
         from vsdpir import DPIR
     except ModuleNotFoundError:
-        raise ModuleNotFoundError("autodb_dpir: vsdpir and pytorch are required for autodb_dpir. "
-                                  "vsdpir can be installed with 'pip install vsdpir'.")
+        raise ModuleNotFoundError(f"autodb_dpir: {dpir_warning}")
 
     if clip.format is None:
         raise ValueError("autodb_dpir: 'Variable-format clips not supported'")
@@ -125,3 +129,53 @@ def autodb_dpir(clip: vs.VideoNode, edgevalue: int = 24,
     )
 
     return core.resize.Bicubic(debl, format=clip.format.id, matrix=matrix)
+
+
+def vsdpir(clip: vs.VideoNode, strength: int = 25, mode: str = 'deblock',
+           matrix: Optional[Union[Matrix, int]] = None,
+           cuda: bool = True, device_index: int = 0,
+           i444: bool = False, **vsdpir_args: Any) -> vs.VideoNode:
+    """
+    A simple vs-dpir wrapper for convenience.
+
+    Converts to RGB -> runs vs-dpir -> converts back to original format.
+    For more information, see https://github.com/cszn/DPIR.
+
+    Dependencies:
+
+    * vs-dpir
+
+    :param clip:            Input clip
+    :param strength:        vs-dpir strength.
+                            Sane values lie between 20-50 for ``mode='deblock'``, and 2-5 for ``mode='denoise'``
+    :param mode:            vs-dpir mode. Valid modes are 'deblock' and 'denoise'.
+    :param matrix:          Enum for the matrix of the input clip. See ``types.Matrix`` for more info.
+                            If `None`, gets matrix from the "_Matrix" prop of the clip
+    :param cuda:            Use CUDA if True, else CPU
+    :param i444:            Forces the returned clip to be YUV444PS instead of the input clip's format
+    :param vsdpir_args:     Additional args to pass onto vs-dpir
+                            (Note: strength, task, and device_type can't be overridden!)
+
+    :return:                Deblocked or denoised clip in either the given clip's format or YUV444PS
+    """
+    try:
+        from vsdpir import DPIR
+    except ModuleNotFoundError:
+        raise ModuleNotFoundError(f"vsdpir: {dpir_warning}")
+
+    if clip.format is None:
+        raise ValueError("vsdpir: 'Variable-format clips not supported'")
+
+    # TO-DO: Add a check to see if the models have been fully downloaded
+    # and if not, run the installer included in vsdpir?
+
+    vsdpir_args |= dict(strength=strength, task=mode, device_type='cuda' if cuda else 'cpu')
+
+    clip_rgb = depth(clip, 32).std.SetFrameProp('_Matrix', intval=matrix)
+    clip_rgb = core.resize.Bicubic(clip_rgb, format=vs.RGBS)
+
+    run_dpir = DPIR(clip_rgb, **vsdpir_args)
+
+    if i444:
+        return core.resize.Bicubic(run_dpir, format=vs.YUV444PS, matrix=matrix)
+    return core.resize.Bicubic(run_dpir, format=clip.format.id, matrix=matrix)
