@@ -165,7 +165,8 @@ def clip_async_render(clip: vs.VideoNode,
 
         y4mformat = f"{y4mformat}p{clip.format.bits_per_sample}" if clip.format.bits_per_sample > 8 else y4mformat
 
-        header = f"YUV4MPEG2 C{y4mformat} W{clip.width} H{clip.height} F{clip.fps_num}:{clip.fps_den} Ip A0:0\n"
+        header = f"YUV4MPEG2 C{y4mformat} W{clip.width} H{clip.height} " \
+            f"F{clip.fps.numerator}:{clip.fps.denominator} Ip A0:0\n"
         outfile.write(header.encode("utf-8"))
 
     if timecodes:
@@ -227,12 +228,6 @@ def find_scene_changes(clip: vs.VideoNode, mode: SceneChangeMode = SceneChangeMo
 
     :return:       List of scene changes.
     """
-    progress = Progress(TextColumn("{task.description}"),
-                        BarColumn(),
-                        TextColumn("{task.completed}/{task.total}"),
-                        TextColumn("{task.percentage:>3.02f}%"),
-                        FPSColumn(),
-                        TimeRemainingColumn())
     frames = []
     clip = clip.resize.Bilinear(640, 360, format=vs.YUV420P8)
 
@@ -241,23 +236,20 @@ def find_scene_changes(clip: vs.VideoNode, mode: SceneChangeMode = SceneChangeMo
     if mode in (SceneChangeMode.SCXVID, SceneChangeMode.WWXD_SCXVID_UNION, SceneChangeMode.WWXD_SCXVID_INTERSECTION):
         clip = clip.scxvid.Scxvid()
 
-    with progress:
-        task = progress.add_task("Detecting scene changes...", total=clip.num_frames)
+    def _cb(n: int, f: vs.VideoFrame) -> None:
+        if mode == SceneChangeMode.WWXD:
+            if get_prop(f, "Scenechange", int) == 1:
+                frames.append(n)
+        elif mode == SceneChangeMode.SCXVID:
+            if get_prop(f, "_SceneChangePrev", int) == 1:
+                frames.append(n)
+        elif mode == SceneChangeMode.WWXD_SCXVID_UNION:
+            if get_prop(f, "Scenechange", int) == 1 or get_prop(f, "_SceneChangePrev", int) == 1:
+                frames.append(n)
+        elif mode == SceneChangeMode.WWXD_SCXVID_INTERSECTION:
+            if get_prop(f, "Scenechange", int) == 1 and get_prop(f, "_SceneChangePrev", int) == 1:
+                frames.append(n)
 
-        def _cb(n: int, f: vs.VideoFrame) -> None:
-            progress.update(task, advance=1)
-            if mode == SceneChangeMode.WWXD:
-                if get_prop(f, "Scenechange", int) == 1:
-                    frames.append(n)
-            elif mode == SceneChangeMode.SCXVID:
-                if get_prop(f, "_SceneChangePrev", int) == 1:
-                    frames.append(n)
-            elif mode == SceneChangeMode.WWXD_SCXVID_UNION:
-                if get_prop(f, "Scenechange", int) == 1 or get_prop(f, "_SceneChangePrev", int) == 1:
-                    frames.append(n)
-            elif mode == SceneChangeMode.WWXD_SCXVID_INTERSECTION:
-                if get_prop(f, "Scenechange", int) == 1 and get_prop(f, "_SceneChangePrev", int) == 1:
-                    frames.append(n)
+    clip_async_render(clip, progress="Detecting scene changes...", callback=_cb)
 
-        clip_async_render(clip, callback=_cb)
     return sorted(frames)
