@@ -1,10 +1,12 @@
 """
-    Helper functions for the main functions in the script.
+    Helper functions for the main functions in this module.
+    Also contains some useful functions for regular scripts.
 """
-from typing import Any, Callable, List, Optional, Sequence, Type, TypeVar, Tuple, Union
+from typing import (Any, Callable, List, Optional, Sequence, Tuple, Type,
+                    TypeVar, Union)
 
 import vapoursynth as vs
-from vsutil import depth
+from vsutil import depth, get_subsampling
 
 from .types import Range
 
@@ -15,7 +17,7 @@ def quick_resample(clip: vs.VideoNode,
                    function: Callable[[vs.VideoNode], vs.VideoNode]
                    ) -> vs.VideoNode:
     """
-    A function to quickly resample to 16/8 bit and back to the original depth.
+    A function to quickly resample to 32/16/8 bit and back to the original depth in a one-liner.
     Useful for filters that only work in 16 bit or lower when you're working in float.
 
     :param clip:      Input clip
@@ -25,12 +27,18 @@ def quick_resample(clip: vs.VideoNode,
     """
     if clip.format is None:
         raise ValueError("quick_resample: 'Variable-format clips not supported'")
-    try:
-        down = depth(clip, 16)
-        filtered = function(down)
+
+    try:  # Excepts all generic because >plugin/script writers being consistent >_>
+        dither = depth(clip, 32)
+        filtered = function(dither)
     except:  # noqa: E722
-        down = depth(clip, 8)
-        filtered = function(down)
+        try:
+            dither = depth(clip, 16)
+            filtered = function(dither)
+        except:  # noqa: E722
+            dither = depth(clip, 8)
+            filtered = function(dither)
+
     return depth(filtered, clip.format.bits_per_sample)
 
 
@@ -209,3 +217,48 @@ def scale_thresh(thresh: float, clip: vs.VideoNode, assume: Optional[int] = None
             else round(thresh/((1 << assume) - 1) * ((1 << clip.format.bits_per_sample) - 1))
     return thresh if clip.format.sample_type == vs.FLOAT or thresh > 1 \
         else round(thresh * ((1 << clip.format.bits_per_sample) - 1))
+
+
+def scale_peak(value: float, peak: float) -> float:
+    """
+    Full-range scale function that scales a value from [0, 255] to [0, peak]
+    """
+    return value * peak / 255
+
+
+def force_mod(x: float, mod: int = 4) -> int:
+    """
+    Force output to fit a specific MOD.
+    Minimum returned value will always be mod².
+    """
+    return mod ** 2 if x < mod ** 2 else int(x / mod + 0.5) * mod
+
+
+def padder(clip: vs.VideoNode,
+           left: int = 32, right: int = 32,
+           top: int = 32, bottom: int = 32) -> vs.VideoNode:
+    """
+    Pads out the pixels on the side by the given amount of pixels.
+    For a 4:2:0 clip, the output must be an even resolution.
+
+    :param clip:        Input clip
+    :param left:        Padding added to the left side of the clip
+    :param right:       Padding added to the right side of the clip
+    :param top:         Padding added to the top side of the clip
+    :param bottom:      Padding added to the bottom side of the clip
+
+    :return:            Padded clip
+    """
+    if clip.format is None:
+        raise ValueError("padder: 'Variable-format clips not supported'")
+
+    width = clip.width+left+right
+    height = clip.height+top+bottom
+
+    if get_subsampling(clip) == '420' and ((width % 2 != 0) or (height % 2 != 0)):
+        raise ValueError("padder: 'Values must result in an even resolution when passing a YUV420 clip!'")
+
+    scaled = core.resize.Point(clip, width, height,
+                               src_top=-1*top, src_left=-1*left,
+                               src_width=width, src_height=height)
+    return core.fb.FillBorders(scaled, left=left, right=right, top=top, bottom=bottom)
